@@ -33,9 +33,9 @@ use constant {    ## no critic (ValuesAndExpressions::ProhibitConstantPragma)
   DEFAULT_REGION => 'us-east-1'
 };                ## end constant
 
-$Data::Dumper::Pair  = COLON;
-$Data::Dumper::Useqq = TRUE;
-$Data::Dumper::Terse = TRUE;
+local $Data::Dumper::Pair  = COLON;
+local $Data::Dumper::Useqq = TRUE;
+local $Data::Dumper::Terse = TRUE;
 
 __PACKAGE__->follow_best_practice;
 
@@ -69,7 +69,7 @@ __PACKAGE__->mk_accessors(
     /
 );
 
-our $VERSION = '1.2.1';
+our $VERSION = '1.2.2';
 
 sub new {
   my ( $class, @options ) = @_;
@@ -1250,7 +1250,7 @@ response.
 
 =head1 VERSION
 
-This documentation refers to version 1.2.1 of C<Amazon::API>.
+This documentation refers to version 1.2.2 of C<Amazon::API>.
 
 =head1 DIAGNOSTICS
 
